Tutorials
============

.. toctree::
   :maxdepth: 1

   notebooks/tutorials/ioi_patching.ipynb
   notebooks/tutorials/attribution_patching.ipynb
   notebooks/tutorials/logit_lens.ipynb
   notebooks/tutorials/future_lens.ipynb
   notebooks/tutorials/function_vectors.ipynb
   notebooks/tutorials/dictionary_learning.ipynb

.. toctree::
   :hidden:

   notebooks/tutorials/sae.ipynb
